@@ -1,14 +1,11 @@
-#ifndef lint
-static char rcsId[]="$Header: /debian/home/gnomecvs/gnome-libs/gtk-xmhtml/callbacks.c,v 1.5 1998/02/12 03:08:30 unammx Exp $";
-#endif
 /*****
 * callbacks.c : XmHTML callback routines
 *
-* This file Version	$Revision: 1.5 $
+* This file Version	$Revision: 1.6 $
 *
 * Creation date:		Mon Dec  2 19:58:52 GMT+0100 1996
-* Last modification: 	$Date: 1998/02/12 03:08:30 $
-* By:					$Author: unammx $
+* Last modification: 	$Date: 1999/07/29 01:26:28 $
+* By:					$Author: sopwith $
 * Current State:		$State: Exp $
 *
 * Author:				newt
@@ -35,6 +32,11 @@ static char rcsId[]="$Header: /debian/home/gnomecvs/gnome-libs/gtk-xmhtml/callba
 /*****
 * ChangeLog 
 * $Log: callbacks.c,v $
+* Revision 1.6  1999/07/29 01:26:28  sopwith
+*
+*
+* Fix all warnings.
+*
 * Revision 1.5  1998/02/12 03:08:30  unammx
 * Merge to Koen's XmHTML 1.1.2 + following fixes:
 *
