@@ -22,8 +22,13 @@
 
 /* "Unsort" a sorted vector path into an ordinary vector path. */
 
+#ifdef LIBART_COMPILATION
+#include "art_rect.h"
+#include "art_point.h"
+#else
 #include <libart_lgpl/art_rect.h>
 #include <libart_lgpl/art_point.h>
+#endif
 
 #ifdef __cplusplus
 extern "C" {
