@@ -25,6 +25,19 @@
 #endif
 #include <sys/types.h>
 
+#ifdef PREFER_DB1
+#ifdef HAVE_DB1_DB_H
+# include <db1/db.h>
+#else
+# ifdef HAVE_DB_185_H
+#  include <db_185.h>
+# else
+#  include <db.h>
+# endif
+#endif
+
+#else
+
 #ifdef HAVE_DB_185_H
 # include <db_185.h>
 #else
@@ -35,6 +48,8 @@
 # endif
 #endif
 
+#endif
+
 #include <string.h>
 #include <unistd.h>
 #include <sys/types.h>
