@@ -296,7 +296,7 @@ gnome_scores_set_logo_label (GnomeScores *gs, gchar *txt, gchar *font,
 	if( font ) 
 		fo = font;
 	else 
-		fo = "-freefont-garamond-*-*-*-*-30-170-*-*-*-*-iso8859-1";
+		fo = "-freefont-garamond-*-*-*-*-30-170-*-*-*-*-iso8859-1,*-r-*";
 
 	if(( f = gdk_fontset_load ( fo ) ))
 		s->font = f;
